@@ -441,6 +441,41 @@ has_harmless_name_change(const decl_base_sptr& f, const decl_base_sptr& s)
 					       0))));
 }
 
+/// Test if two decls represents a harmful name change.
+///
+/// A harmful name change is a name change that is not harmless, so
+/// this function uses the function has_harmless_name_change.
+///
+/// @param f the first decl to consider in the comparison.
+///
+/// @param s the second decl to consider in the comparison.
+///
+/// @return true iff decl @p s represents a harmful name change over
+/// @p f.
+bool
+has_harmful_name_change(const decl_base_sptr& f, const decl_base_sptr& s)
+{return decl_name_changed(f, s) && ! has_harmless_name_change(f, s);}
+
+/// Test if a diff node represents a harmful name change.
+///
+/// A harmful name change is a name change that is not harmless, so
+/// this function uses the function has_harmless_name_change.
+///
+/// @param f the first decl to consider in the comparison.
+///
+/// @param s the second decl to consider in the comparison.
+///
+/// @return true iff decl @p s represents a harmful name change over
+/// @p f.
+bool
+has_harmful_name_change(const diff* dif)
+{
+  decl_base_sptr f = is_decl(dif->first_subject()),
+    s = is_decl(dif->second_subject());
+
+  return has_harmful_name_change(f, s);
+}
+
 /// Test if a class_diff node has non-static members added or
 /// removed.
 ///
@@ -885,14 +920,21 @@ is_mostly_distinct_diff(const diff *d)
     return true;
 
   // Let's consider that 'd' is a type diff ...
-  type_diff_base* td = const_cast<type_diff_base*>(is_type_diff(d));
+  diff * td = const_cast<type_diff_base*>(is_type_diff(d));
   if (!td)
     {
       // ... or a function parameter diff.  In which case, let's get
-      // its child type diff.
+      // its child type diff ...
       fn_parm_diff *pd = const_cast<fn_parm_diff*>(is_fn_parm_diff(d));
       if (pd)
-	td = const_cast<type_diff_base*>(is_type_diff(pd->type_diff().get()));
+	{
+	  td = const_cast<type_diff_base*>(is_type_diff(pd->type_diff().get()));
+	  if (!td)
+	    // if the diff of the fn_parm_diff is a a distinct diff
+	    // then handle it.
+	    td = const_cast<distinct_diff*>
+	      (is_distinct_diff(pd->type_diff().get()));
+	}
       else
 	return false;
     }
@@ -1041,6 +1083,48 @@ has_fn_parm_type_top_cv_qual_change(const diff* diff)
   return false;
 }
 
+/// Test if a type diff only carries a CV qualifier-only change.
+///
+/// @param type_dif the type dif to consider.
+///
+/// @return true iff the type_diff carries a CV qualifier only change.
+static bool
+type_diff_has_cv_qual_change_only(const diff *type_dif)
+{
+  if (!is_type_diff(type_dif))
+    return false;
+
+  if (is_pointer_diff(type_dif))
+    type_dif = peel_pointer_diff(type_dif);
+  else if (is_reference_diff(type_dif))
+    type_dif = peel_reference_diff(type_dif);
+
+  const type_base *f = 0;
+  const type_base *s = 0;
+  if (const distinct_diff *d = is_distinct_diff(type_dif))
+    {
+      if (is_qualified_type(d->first()) == is_qualified_type(d->second()))
+	return false;
+      else
+	{
+	  f = is_type(d->first()).get();
+	  s = is_type(d->second()).get();
+	}
+    }
+  else if (const qualified_type_diff *d = is_qualified_type_diff(type_dif))
+    {
+      f = is_type(d->first_qualified_type()).get();
+      s = is_type(d->second_qualified_type()).get();
+    }
+  else
+    return false;
+
+  f = peel_qualified_type(f);
+  s = peel_qualified_type(s);
+
+  return *f == *s;
+}
+
 /// Test if an @ref fn_parm_diff node has a cv qualifier change on the
 /// type of the function parameter. That is, we are looking for
 /// changes like 'const char*' to 'char*'.
@@ -1062,37 +1146,129 @@ has_fn_parm_type_cv_qual_change(const diff* dif)
     return false;
 
   const diff *type_dif = parm_diff->type_diff().get();
-  if (is_pointer_diff(type_dif))
-    type_dif = peel_pointer_diff(type_dif);
-  else if (is_reference_diff(type_dif))
-    type_dif = peel_reference_diff(type_dif);
-
-  const type_base *f = 0;
-  const type_base *s = 0;
-  if (const distinct_diff *d = is_distinct_diff(type_dif))
-    {
-      if (is_qualified_type(d->first()) != is_qualified_type(d->second()))
-	{
-	  f = is_type(d->first()).get();
-	  s = is_type(d->second()).get();
-	}
-      else
-	return false;
-    }
-  else if (const qualified_type_diff *d = is_qualified_type_diff(type_dif))
-    {
-      f = is_type(d->first_qualified_type()).get();
-      s = is_type(d->second_qualified_type()).get();
-    }
-  else
-    return false;
-
-  f = peel_qualified_type(f);
-  s = peel_qualified_type(s);
-
-  return *f == *s;
+  return type_diff_has_cv_qual_change_only(type_dif);
 }
 
+/// Test if a function type or decl diff node carries a CV
+/// qualifier-only change on its return type.
+///
+/// @param the dif to consider.  Note that if this is neither a
+/// function type nor decl diff node, the function returns false.
+///
+/// @return true iff @p dif is a function decl or type diff node which
+/// carries a CV qualifier-only change on its return type.
+static bool
+has_fn_return_type_cv_qual_change(const diff* dif)
+{
+  const function_type_diff* fn_type_diff = is_function_type_diff(dif);
+  if (!fn_type_diff)
+    if (const function_decl_diff* fn_decl_diff = is_function_decl_diff(dif))
+      fn_type_diff = fn_decl_diff->type_diff().get();
+
+  if (!fn_type_diff)
+    return false;
+
+  const diff* return_type_diff = fn_type_diff->return_type_diff().get();
+  return type_diff_has_cv_qual_change_only(return_type_diff);
+}
+
+/// Test if a diff node carries a void* to pointer type change.
+///
+/// Note that this function looks through typedef and qualifier types
+/// to find the void pointer.
+///
+/// @param dif the diff node to consider.
+///
+/// @return true iff @p dif carries a void* to pointer type change.
+static bool
+has_void_ptr_to_ptr_change(const diff* dif)
+{
+  dif = peel_typedef_diff(dif);
+
+  if (const distinct_diff *d = is_distinct_diff(dif))
+    {
+      const type_base *f = is_type(d->first().get());
+      const type_base *s = is_type(d->second().get());
+
+      f = peel_qualified_or_typedef_type(f);
+      s = peel_qualified_or_typedef_type(s);
+
+      if (is_void_pointer_type(f)
+	  && is_pointer_type(s)
+	  && !is_void_pointer_type(s)
+	  && f->get_size_in_bits() == s->get_size_in_bits())
+	return true;
+    }
+  else if (const pointer_diff *d = is_pointer_diff(dif))
+    {
+      const type_base *f = is_type(d->first_pointer()).get();
+      const type_base *s = is_type(d->second_pointer()).get();
+
+      f = peel_qualified_or_typedef_type(f);
+      s = peel_qualified_or_typedef_type(s);
+
+      if (is_void_pointer_type(f)
+	  && is_pointer_type(s)
+	  && !is_void_pointer_type(s)
+	  && f->get_size_in_bits() == s->get_size_in_bits())
+	return true;
+    }
+  else if (const qualified_type_diff *d = is_qualified_type_diff(dif))
+    {
+      const type_base *f = is_type(d->first_qualified_type()).get();
+      const type_base *s = is_type(d->second_qualified_type()).get();
+
+      f = peel_qualified_or_typedef_type(f);
+      s = peel_qualified_or_typedef_type(s);
+
+      if (is_void_pointer_type(f)
+	  && is_pointer_type(s)
+	  && !is_void_pointer_type(s)
+	  && f->get_size_in_bits() == s->get_size_in_bits())
+	return true;
+    }
+
+  return false;
+}
+
+/// Test if a diff node carries a benign change to the size of a
+/// variable of type array.
+///
+/// A benign size change is a change in size (from or to infinite) of
+/// the array as expressed by the debug info, but when the *ELF* size
+/// (what really matters) of the variable object hasn't changed.  This
+/// happens when the debug info emitter did have trouble figuring out
+/// the actual size of the array.
+///
+/// @param dif the diff node to consider.
+///
+/// @return true iff @p dif contains the benign array type size change.
+static bool
+has_benign_infinite_array_change(const diff* dif)
+{
+  if (const var_diff* var_dif = is_var_diff(dif))
+    {
+      if (!var_dif->first_var()->get_symbol()
+	  || var_dif->second_var()->get_symbol())
+	return false;
+
+      if (var_dif->first_var()->get_symbol()->get_size()
+	  != var_dif->second_var()->get_symbol()->get_size())
+	return false;
+
+      const diff *d = var_dif->type_diff().get();
+      if (!d)
+	return false;
+      d = peel_qualified_diff(d);
+      if (const array_diff *a = is_array_diff(d))
+	{
+	  array_type_def_sptr f = a->first_array(), s = a->second_array();
+	  if (f->is_infinite() != s->is_infinite())
+	    return true;
+	}
+    }
+  return false;
+}
 /// Detect if the changes carried by a given diff node are deemed
 /// harmless and do categorize the diff node accordingly.
 ///
@@ -1149,6 +1325,15 @@ categorize_harmless_diff_node(diff *d, bool pre)
       if (has_fn_parm_type_cv_qual_change(d))
 	category |= FN_PARM_TYPE_CV_CHANGE_CATEGORY;
 
+      if (has_fn_return_type_cv_qual_change(d))
+	category |= FN_RETURN_TYPE_CV_CHANGE_CATEGORY;
+
+      if (has_void_ptr_to_ptr_change(d))
+	category |= VOID_PTR_TO_PTR_CHANGE_CATEGORY;
+
+      if (has_benign_infinite_array_change(d))
+	category |= BENIGN_INFINITE_ARRAY_CHANGE_CATEGORY;
+
       if (category)
 	{
 	  d->add_to_local_and_inherited_categories(category);
