@@ -66,16 +66,20 @@ char_is_comment_start(int b);
 ///@param include_square_bracket if true, consider square brackets as
 /// delimiters
 ///
+/// @param include_equal if true, consider the equal character ('=')
+/// as a delimiter.
+///
 /// @return true iff @p b is a delimiter.
 static bool
 char_is_delimiter(int b, bool include_white_space = true,
-		  bool include_square_bracket = true)
+		  bool include_square_bracket = true,
+		  bool include_equal = true)
 {
   return ((include_square_bracket && (b == '['))
 	  || (include_square_bracket && (b == ']'))
 	  || b == '{'
 	  || b == '}'
-	  || b == '='
+	  || (include_equal && (b == '='))
 	  || b == ','
 	  || (include_white_space && char_is_white_space(b))
 	  || char_is_comment_start(b));
@@ -84,6 +88,10 @@ char_is_delimiter(int b, bool include_white_space = true,
 /// Return true iff a given character can be part of a property
 /// value.
 ///
+/// Note that white spaces, square brackets and the equal character can be
+/// part of a property value.  The reason why we accept the equal
+/// character is because it can appear in an URL.
+///
 /// @param b the character to test against.
 ///
 /// @return true iff @p b is a character that can be part of a
@@ -92,7 +100,8 @@ static bool
 char_is_property_value_char(int b)
 {
   if (char_is_delimiter(b, /*include_white_space=*/false,
-			/*include_square_bracket=*/false)
+			/*include_square_bracket=*/false,
+			/*include_equal=*/false)
       || b == '\n')
     return false;
   return true;
