@@ -1445,11 +1445,6 @@ make_path_absolute(const char*p)
   return result;
 }
 
-/// The name of the artificial private type suppression specification
-/// that is auto-generated by libabigail to suppress change reports
-/// about types that are not defined in public headers.
-const char* PRIVATE_TYPES_SUPPR_SPEC_NAME =
-  "Artificial private types suppression specification";
 
 /// This is a sub-routine of gen_suppr_spec_from_headers.
 ///
@@ -1482,7 +1477,7 @@ handle_fts_entry(const FTSENT *entry,
 	{
 	  if (!suppr)
 	    {
-	      suppr.reset(new type_suppression(PRIVATE_TYPES_SUPPR_SPEC_NAME,
+	      suppr.reset(new type_suppression(get_private_types_suppr_spec_label(),
 					       /*type_name_regexp=*/"",
 					       /*type_name=*/""));
 
@@ -1511,9 +1506,15 @@ handle_fts_entry(const FTSENT *entry,
 type_suppression_sptr
 gen_suppr_spec_from_headers(const string& headers_root_dir)
 {
-  char* paths[] = {const_cast<char*>(headers_root_dir.c_str()), 0};
   type_suppression_sptr result;
 
+  if (headers_root_dir.empty())
+    // We were given no headers root dir so the resulting suppression
+    // specification shall be empty.
+    return result;
+
+  char* paths[] = {const_cast<char*>(headers_root_dir.c_str()), 0};
+
   FTS *file_hierarchy = fts_open(paths, FTS_LOGICAL|FTS_NOCHDIR, NULL);
   if (!file_hierarchy)
     return result;
