@@ -1718,6 +1718,16 @@ InOutSpec in_out_specs[] =
    "data/test-diff-suppr/test38-char-class-in-ini-report-0.txt",
    "output/test-diff-suppr/test38-char-class-in-ini-report-0.txt"
   },
+  {
+    "data/test-diff-suppr/test39-opaque-type-v0.o",
+    "data/test-diff-suppr/test39-opaque-type-v1.o",
+    "data/test-diff-suppr/test39-public-headers-dir",
+    "data/test-diff-suppr/test39-public-headers-dir",
+    "",
+    "--no-default-suppression",
+    "data/test-diff-suppr/test39-opaque-type-report-0.txt",
+    "output/test-diff-suppr/test39-opaque-type-report-0.txt"
+  },
   // This should be the last entry
   {NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL}
 };
